@@ -6,6 +6,10 @@ import re
 AA_DISCORDFORMATTER_ADDITIONAL_PING_TARGETS = clean_setting('AA_DISCORDFORMATTER_ADDITIONAL_PING_TARGETS', [])
 AA_DISCORDFORMATTER_ADDITIONAL_FLEET_TYPES = clean_setting('AA_DISCORDFORMATTER_ADDITIONAL_FLEET_TYPES', [])
 AA_DISCORDFORMATTER_ADDITIONAL_PING_WEBHOOKS = clean_setting('AA_DISCORDFORMATTER_ADDITIONAL_PING_WEBHOOKS', [])
+AA_DISCORDFORMATTER_WEBHOOK_EMBED_PING = clean_setting('AA_DISCORDFORMATTER_WEBHOOK_EMBED_PING', False)
+AA_DISCORDFORMATTER_FLEET_COMMS = clean_setting('AA_DISCORDFORMATTER_FLEET_COMMS', [])
+AA_DISCORDFORMATTER_FLEET_DOCTRINES = clean_setting('AA_DISCORDFORMATTER_FLEET_DOCTRINES', [])
+AA_DISCORDFORMATTER_FLEET_FORMUP_LOCATIONS = clean_setting('AA_DISCORDFORMATTER_FLEET_FORMUP_LOCATIONS', [])
 
 
 def get_site_url():  # regex sso url
