@@ -1,4 +1,4 @@
-/* global timezonesInstalled, siteUrl, pingCreator */
+/* global discordPingformatterSettings */
 
 jQuery(document).ready(function($) {
     /* Functions
@@ -70,7 +70,34 @@ jQuery(document).ready(function($) {
      * @returns {undefined}
      */
     var sanitizeInput = (function(input) {
-        return input.replace(/<(|\/|[^>\/bi]|\/[^>bi]|[^\/>][^>]+|\/[^>][^>]+)>/g, '');
+        if(input) {
+            return input.replace(/<(|\/|[^>\/bi]|\/[^>bi]|[^\/>][^>]+|\/[^>][^>]+)>/g, '');
+        } else {
+            return input;
+        }
+    });
+
+    /**
+     * send an embedded message to a Discord webhook
+     *
+     * @param {string} discordWebhook
+     * @param {string} content
+     * @param {array} embeds
+     */
+    var sendEmbeddedDiscordPing = (function(discordWebhook, content, embeds) {
+        var request = new XMLHttpRequest();
+
+        request.open('POST', discordWebhook);
+        request.setRequestHeader('Content-type', 'application/json');
+
+        var params = {
+            username: '',
+            avatar_url: '',
+            content: content,
+            embeds: [embeds]
+        };
+
+        request.send(JSON.stringify(params));
     });
 
     /**
@@ -82,23 +109,48 @@ jQuery(document).ready(function($) {
     var sendDiscordPing = (function(discordWebhook, discordPingText) {
         var request = new XMLHttpRequest();
 
-        request.open("POST", discordWebhook);
+        request.open('POST', discordWebhook);
         request.setRequestHeader('Content-type', 'application/json');
 
         var params = {
-            username: "",
-            avatar_url: "",
+            username: '',
+            avatar_url: '',
             content: discordPingText
         };
 
         request.send(JSON.stringify(params));
     });
 
-    // generate the ping text
+    /**
+     * convert hex color code in something Discord can handle
+     *
+     * @param {string} hexValue
+     */
+    var hexToDecimal = (function(hexValue) {
+        return parseInt(hexValue.replace('#',''), 16);
+    });
+
+    /**
+     * convert the datepicker info into an URL that the
+     * aa-tomezones module understands
+     *
+     * @param {string} formupTime
+     */
+    var getTimezonesUrl = (function(formupTime) {
+        var formupTimestamp = ((new Date(formupTime + ' UTC')).getTime()) / 1000;
+        var timezonesUrl = discordPingformatterSettings.siteUrl + 'timezones/?#' + formupTimestamp;
+
+        return timezonesUrl;
+    });
+
+    /**
+     * create the ping text
+     */
     var generateDiscordPing = (function() {
         var pingTarget = sanitizeInput($('select#pingTarget option:selected').val());
         var pingTargetText = sanitizeInput($('select#pingTarget option:selected').text());
         var fleetType = sanitizeInput($('select#fleetType option:selected').val());
+        var webhookEmbedColor = sanitizeInput($('select#fleetType option:selected').data('embed-color'));
         var fcName = sanitizeInput($('input#fcName').val());
         var fleetName = sanitizeInput($('input#fleetName').val());
         var formupLocation = sanitizeInput($('input#formupLocation').val());
@@ -117,6 +169,9 @@ jQuery(document).ready(function($) {
 
         $('.aa-discord-ping-formatter-ping').show();
 
+        var discordWebhookPingTextHeader = '';
+        var discordWebhookPingTextContent = '';
+        var discordWebhookPingTextFooter = '';
         var discordPingText = '';
 
         // determine pingTargetText
@@ -133,22 +188,32 @@ jQuery(document).ready(function($) {
             webhookPingTarget = '<@&' + pingTarget + '>';
         }
 
+        // separator
         discordPingText += ' :: ';
+
+        // fleet announcement
         discordPingText += '**';
 
-        // check if it's a preping or not
+        // check if it's a pre-ping or not
         if($('input#prePing').is(':checked')) {
             discordPingText += '### PRE PING ###';
+            discordWebhookPingTextHeader += '### PRE PING ###';
 
             if(fleetType !== '') {
-                discordPingText += ' / ' + fleetType + ' Fleet'
+                discordPingText += ' / ' + fleetType + ' Fleet';
+                discordWebhookPingTextHeader += ' / ' + fleetType + ' Fleet';
+            } else {
+                discordPingText += ' / Fleet';
+                discordWebhookPingTextHeader += ' / Fleet';
             }
         } else {
             if(fleetType !== '') {
                 discordPingText += fleetType + ' ';
+                discordWebhookPingTextHeader += fleetType + ' ';
             }
 
             discordPingText += 'Fleet is up';
+            discordWebhookPingTextHeader += 'Fleet is up';
         }
 
         discordPingText += '**' + "\n";
@@ -156,31 +221,36 @@ jQuery(document).ready(function($) {
         // check if FC name is available
         if(fcName !== '') {
             discordPingText += "\n" + '**FC:** ' + fcName;
+            discordWebhookPingTextContent += "\n" + '**FC:** ' + fcName;
         }
 
         // check if fleet name is available
         if(fleetName !== '') {
             discordPingText += "\n" + '**Fleet Name:** ' + fleetName;
+            discordWebhookPingTextContent += "\n" + '**Fleet Name:** ' + fleetName;
         }
 
-        // check if formup location is available
+        // check if form-up location is available
         if(formupLocation !== '') {
             discordPingText += "\n" + '**Formup Location:** ' + formupLocation;
+            discordWebhookPingTextContent += "\n" + '**Formup Location:** ' + formupLocation;
         }
 
-        // check if formup time is available
+        // check if form-up time is available
         if($('input#formupTimeNow').is(':checked')) {
             discordPingText += "\n" + '**Formup Time:** NOW';
+            discordWebhookPingTextContent += "\n" + '**Formup Time:** NOW';
         } else {
             if(formupTime !== '') {
                 discordPingText += "\n" + '**Formup Time:** ' + formupTime;
+                discordWebhookPingTextContent += "\n" + '**Formup Time:** ' + formupTime;
 
                 // get the timestamp and build the link to the timezones module if it's installed
-                if(timezonesInstalled === true) {
-                    var formupTimestamp = ((new Date(formupTime + ' UTC')).getTime()) / 1000;
-                    var timezonesUrl = siteUrl + 'timezones/?#' + formupTimestamp;
+                if(discordPingformatterSettings.timezonesInstalled === true) {
+                    var timezonesUrl = getTimezonesUrl(formupTime);
 
                     discordPingText += ' - ' + timezonesUrl;
+                    discordWebhookPingTextContent += ' ([Time Zone Conversion](' + timezonesUrl + '))';
                 }
             }
         }
@@ -188,21 +258,25 @@ jQuery(document).ready(function($) {
         // check if fleet comms is available
         if(fleetComms !== '') {
             discordPingText += "\n" + '**Comms:** ' + fleetComms;
+            discordWebhookPingTextContent += "\n" + '**Comms:** ' + fleetComms;
         }
 
         // check if doctrine is available
         if(fleetDoctrine !== '') {
             discordPingText += "\n" + '**Ships / Doctrine:** ' + fleetDoctrine;
+            discordWebhookPingTextContent += "\n" + '**Ships / Doctrine:** ' + fleetDoctrine;
         }
 
         // check if srp is available
         if(fleetSrp !== '') {
             discordPingText += "\n" + '**SRP:** ' + fleetSrp;
+            discordWebhookPingTextContent += "\n" + '**SRP:** ' + fleetSrp;
         }
 
         // check if additional information is available
         if(additionalInformation !== '') {
             discordPingText += "\n\n" + '**Additional Information**:' + "\n" + additionalInformation;
+            discordWebhookPingTextContent += "\n\n" + '**Additional Information**:' + "\n" + additionalInformation;
         }
 
         $('.aa-discord-ping-formatter-ping-text').html('<p>' + nl2br(discordPingTarget + discordPingText) + '</p>');
@@ -210,15 +284,41 @@ jQuery(document).ready(function($) {
         // ping it directly if a webhook is selected
         if(discordWebhook !== false && discordWebhook !== '') {
             // add ping creator at the end
-            if(pingCreator !== '') {
-                discordPingText += "\n\n" + '*(Ping sent by: ' + pingCreator + ')*'
+            if(discordPingformatterSettings.pingCreator !== '') {
+                discordPingText += "\n\n" + '*(Ping sent by: ' + discordPingformatterSettings.pingCreator + ')*';
+                discordWebhookPingTextFooter = '(Ping sent by: ' + discordPingformatterSettings.pingCreator + ')';
             }
 
             // send the ping
-            sendDiscordPing(discordWebhook, webhookPingTarget + discordPingText);
+            if(discordPingformatterSettings.embedPing === true) {
+                var embedColor = '#FAA61A';
+
+                if(fleetType !== '' && embedColor !== '') {
+                    embedColor = webhookEmbedColor;
+                }
+
+                sendEmbeddedDiscordPing(
+                    discordWebhook,
+                    webhookPingTarget + ' :: **' + discordWebhookPingTextHeader + ' under ' + fcName + '**' + "\n" + '** **',
+                    // embedded content » https://discohook.org/ - https://leovoel.github.io/embed-visualizer/
+                    {
+                        'title': '**.: Fleet Details :.**',
+                        'description': discordWebhookPingTextContent,
+                        'color': hexToDecimal(embedColor),
+                        'footer': {
+                            'text': discordWebhookPingTextFooter
+                        }
+                    }
+                );
+            } else {
+                sendDiscordPing(discordWebhook, webhookPingTarget + discordPingText);
+            }
 
             // tell the FC that it's already pinged
-            showSuccess('Success, your ping has been sent to your Discord.', '.aa-discord-ping-formatter-ping-copyresult');
+            showSuccess(
+                'Success, your ping has been sent to your Discord.',
+                '.aa-discord-ping-formatter-ping-copyresult'
+            );
         }
     });
 
@@ -239,7 +339,10 @@ jQuery(document).ready(function($) {
          * @param {type} e
          */
         clipboardDiscordPingData.on('success', function(e) {
-            showSuccess('Success, Ping copied to clipboard. Now be a good FC and throw it in your Discord so you actually get some people in fleet.', '.aa-discord-ping-formatter-ping-copyresult');
+            showSuccess(
+                'Success, Ping copied to clipboard. Now be a good FC and throw it in your Discord so you actually get some people in fleet.',
+                '.aa-discord-ping-formatter-ping-copyresult'
+            );
 
             e.clearSelection();
             clipboardDiscordPingData.destroy();
@@ -249,7 +352,10 @@ jQuery(document).ready(function($) {
          * copy error
          */
         clipboardDiscordPingData.on('error', function() {
-            showError('Error, Ping not copied to clipboard.', '.aa-discord-ping-formatter-ping-copyresult');
+            showError(
+                'Error, Ping not copied to clipboard.',
+                '.aa-discord-ping-formatter-ping-copyresult'
+            );
 
             clipboardDiscordPingData.destroy();
         });
